@@ -40,7 +40,8 @@ def make_get_request(endpoint: str, params: dict = None):
         "Authorization": f"Bearer {api_key}",
     }
     response = requests.get(base_url + endpoint, headers=headers, params=params)
-    ic(response.content.decode())
+    if response.status_code != 200:
+        ic(response.content.decode())
     response.raise_for_status()
     return response.json()
 
@@ -123,3 +124,10 @@ def get_collection_schema(collection_name: str):
     return make_get_request(
         endpoint=f"/collection/{collection_name}/schema",
     )
+
+
+def delete_collection(collection_name: str):
+    return make_delete_request(
+        endpoint=f"/collection/{collection_name}/delete",
+        json=None,
+    )
